@@ -2,8 +2,16 @@
 mundipy.cache provides spatial caches as function decorators.
 """
 
+from functools import lru_cache
 import geopandas as gpd
 from shapely.geometry.base import BaseGeometry
+import pyproj
+
+@lru_cache(maxsize=64)
+def pyproj_transform(from_crs, to_crs):
+    """ Returns a pyproj transform() function between two CRS, in 'EPSG:xxxx' format."""
+    return pyproj.Transformer.from_crs(pyproj.CRS(from_crs),
+        pyproj.CRS(to_crs), always_xy=True).transform
 
 def spatial_cache_footprint(fn, maxsize=128):
 	"""
